#region Copyright & License

//
// Author: Ian Davis <ian.f.davis@gmail.com> Copyright (c) 2007, Ian Davs
//
// Portions of this software were developed for NUnit. See NOTICE.txt for more
// information. 
//
// Licensed under the Apache License, Version 2.0 (the "License"); you may not
// use this file except in compliance with the License. You may obtain a copy of
// the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
// WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
// License for the specific language governing permissions and limitations under
// the License.
//

#endregion

using System;
using Ensurance.MessageWriters;
using Ensurance.Properties;

namespace Ensurance.Constraints
{
    /// <summary>
    /// SameAsConstraint tests whether an object is identical to the object
    /// passed to its constructor
    /// </summary>
    public class SameAsConstraint : Constraint
    {
        private object _expected;

        /// <summary>
        /// Initializes a new instance of the <see cref="SameAsConstraint"/>
        /// class.
        /// </summary>
        /// <param name="expected">The expected object.</param>
        public SameAsConstraint( object expected )
        {
            _expected = expected;
        }

        /// <summary>
        /// Test whether the constraint is satisfied by a given value
        /// </summary>
        /// <param name="actual">The value to be tested</param>
        /// <returns>True for success, false for failure</returns>
        public override bool Matches( object actual )
        {
            Actual = actual;

            return ReferenceEquals( _expected, actual );
        }

        /// <summary>
        /// Write the constraint description to a MessageWriter
        /// </summary>
        /// <exception cref="ArgumentNullException">if the message writer is null.</exception>
        /// <param name="writer">The writer on which the description is displayed</param>
        public override void WriteDescriptionTo( MessageWriter writer )
        {
            if ( writer == null )
            {
                throw new ArgumentNullException( "writer" );
            }

            writer.WritePredicate( Resources.SameAs );
            writer.WriteExpectedValue( _expected );
        }
    }
}